pub struct AsyncProducts;Available on crate feature
async only.Expand description
Async wrapper for Product.products(for:).
Fetches products from the App Store for a set of product identifiers.
Notes
On macOS Sandbox / Xcode previews you must configure a StoreKit Configuration File in your scheme for products to be returned.
Implementations
Sourceimpl AsyncProducts
impl AsyncProducts
Sourcepub fn fetch<I, S>(identifiers: I) -> Result<ProductsFuture, StoreKitError>
pub fn fetch<I, S>(identifiers: I) -> Result<ProductsFuture, StoreKitError>
Asynchronously fetch products for the given identifiers.
Equivalent to Product.products(for: identifiers) in Swift.
Errors
Returns an error if the App Store request fails or the product identifiers cannot be encoded.