pub struct AsyncPurchase;Available on crate feature
async only.Expand description
Async wrapper for Product.purchase(options:).
Initiates an in-app purchase and resolves to the PurchaseResult.
The purchase sheet is shown on the main actor (equivalent to Swift’s
@MainActor).
Notes
- The future must be awaited until completion; cancellation is not
supported by the
StoreKit2 purchase API. Transaction.currentEntitlementsandTransaction.updates(multi-fire streams) are deferred to Tier 2.
Implementations
Sourceimpl AsyncPurchase
impl AsyncPurchase
Sourcepub fn buy(
product_id: &str,
options: &[PurchaseOption],
) -> Result<PurchaseFuture, StoreKitError>
pub fn buy( product_id: &str, options: &[PurchaseOption], ) -> Result<PurchaseFuture, StoreKitError>
Asynchronously purchase a product.
Equivalent to product.purchase(options:) in Swift.
Errors
Returns an error if the product cannot be found, the purchase fails, or the options cannot be encoded.