SubscriptionInfo

Struct SubscriptionInfo 

pub struct SubscriptionInfo {
    pub introductory_offer: Option<SubscriptionOffer>,
    pub promotional_offers: Vec<SubscriptionOffer>,
    pub win_back_offers: Vec<SubscriptionOffer>,
    pub subscription_group_id: String,
    pub subscription_period: SubscriptionPeriod,
    pub group_level: Option<i64>,
    pub group_display_name: Option<String>,
}
Wraps StoreKit.Product.SubscriptionInfo.

Fields

introductory_offer: Option<SubscriptionOffer>

Introductory offer reported by StoreKit.

promotional_offers: Vec<SubscriptionOffer>

Promotional offers reported by StoreKit.

win_back_offers: Vec<SubscriptionOffer>

Win-back offers reported by StoreKit.

subscription_group_id: String

Subscription group identifier reported by StoreKit.

subscription_period: SubscriptionPeriod

Subscription period reported by StoreKit.

group_level: Option<i64>

Subscription group level reported by StoreKit.

group_display_name: Option<String>

Subscription group display name reported by StoreKit.

Implementations

Source

impl SubscriptionInfo

pub fn is_eligible_for_intro_offer(&self) -> Result<bool, StoreKitError>

Returns whether StoreKit reports that this subscription group is eligible for an introductory offer.

pub fn is_eligible_for_intro_offer_for( group_id: &str, ) -> Result<bool, StoreKitError>

Returns whether StoreKit reports that the supplied subscription group is eligible for an introductory offer.

pub fn status(&self) -> Result<Vec<SubscriptionStatus>, StoreKitError>

Fetches the StoreKit subscription statuses for this subscription group.

pub fn status_for( group_id: &str, ) -> Result<Vec<SubscriptionStatus>, StoreKitError>

Fetches the StoreKit subscription statuses for the supplied subscription group identifier.

pub fn status_for_transaction( transaction_id: u64, ) -> Result<Option<SubscriptionStatus>, StoreKitError>

Fetches the StoreKit subscription status for the supplied transaction identifier.