AsyncStorefront

Struct AsyncStorefront 

pub struct AsyncStorefront;
Available on crate feature async only.
Async wrapper for Storefront.current.

Returns the current App Store storefront, or None if no storefront is available (e.g. the device is not connected to the App Store).

Implementations

Source

impl AsyncStorefront

pub fn current() -> StorefrontCurrentFuture

Asynchronously fetch Storefront.current.

Equivalent to Storefront.current in Swift.